import os
from argparse import Namespace

import pytest

from arkindex.mock import MockApiClient
from arkindex_worker.worker.base import BaseWorker
from worker_file_import.worker import ImportWorker


@pytest.fixture(autouse=True)
def _setup_environment(responses, monkeypatch) -> None:
    """Setup needed environment variables"""

    # Allow accessing remote API schemas
    # defaulting to the prod environment
    schema_url = os.environ.get(
        "ARKINDEX_API_SCHEMA_URL",
        "https://demo.arkindex.org/api/v1/openapi/?format=openapi-json",
    )
    responses.add_passthru(schema_url)

    # Set schema url in environment
    os.environ["ARKINDEX_API_SCHEMA_URL"] = schema_url
    # Setup a fake worker run ID
    os.environ["ARKINDEX_WORKER_RUN_ID"] = "1234-file-import"
    # Setup a fake corpus ID
    os.environ["ARKINDEX_CORPUS_ID"] = "1234-corpus-id"

    # Setup a mock api client instead of using a real one
    def mock_setup_api_client(self):
        self.api_client = MockApiClient()

    monkeypatch.setattr(BaseWorker, "setup_api_client", mock_setup_api_client)


@pytest.fixture()
def mock_worker(monkeypatch):
    monkeypatch.setattr(ImportWorker, "configure", lambda *args, **kwargs: True)

    worker = ImportWorker()
    worker.args = Namespace(dev=False)

    worker._corpus_id = "aaaaaaaa-aaaa-aaaa-aaaa-aaaaaaaaaaaa"
    worker.worker_run_id = "bbbbbbbb-aaaa-aaaa-aaaa-aaaaaaaaaaaa"

    worker.folder_type = "folder"
    worker.page_type = "page"

    yield worker

    assert not worker.api_client.responses
